==> glib2-2.32.4-arm-1.tgz: install/doinst.sh <==
( cd usr/doc/glib-2.32.4 ; rm -rf html )
( cd usr/doc/glib-2.32.4 ; ln -sf /usr/share/gtk-doc/html/gobject html )
( cd usr/lib ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.3200.4 libgthread-2.0.so.0 )
( cd usr/lib ; rm -rf libgmodule-2.0.so )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.3200.4 libgmodule-2.0.so )
( cd usr/lib ; rm -rf libgio-2.0.so.0 )
( cd usr/lib ; ln -sf libgio-2.0.so.0.3200.4 libgio-2.0.so.0 )
( cd usr/lib ; rm -rf libgio-2.0.so )
( cd usr/lib ; ln -sf libgio-2.0.so.0.3200.4 libgio-2.0.so )
( cd usr/lib ; rm -rf libglib-2.0.so.0 )
( cd usr/lib ; ln -sf libglib-2.0.so.0.3200.4 libglib-2.0.so.0 )
( cd usr/lib ; rm -rf libgobject-2.0.so )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.3200.4 libgobject-2.0.so )
( cd usr/lib ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.3200.4 libgobject-2.0.so.0 )
( cd usr/lib ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.3200.4 libgmodule-2.0.so.0 )
( cd usr/lib ; rm -rf libglib-2.0.so )
( cd usr/lib ; ln -sf libglib-2.0.so.0.3200.4 libglib-2.0.so )
( cd usr/lib ; rm -rf libgthread-2.0.so )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.3200.4 libgthread-2.0.so )

# Handle the incoming configuration files:
config() {
  for infile in $1; do
    NEW="$infile"
    OLD="`dirname $NEW`/`basename $NEW .new`"
    # If there's no config file by that name, mv it over:
    if [ ! -r $OLD ]; then
      mv $NEW $OLD
    elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then
      # toss the redundant copy
      rm $NEW
    fi
    # Otherwise, we leave the .new copy for the admin to consider...
  done
}

# Prepare the new configuration files
for file in etc/profile.d/libglib2.csh.new etc/profile.d/libglib2.sh.new ; do
  if test -e $(dirname $file)/$(basename $file .new) ; then
    if [ ! -x $(dirname $file)/$(basename $file .new) ]; then
      chmod 644 $file
     else
      chmod 755 $file
    fi
  fi
  config $file
done

# Try to run these.  If they fail, no biggie.
chroot . /usr/bin/glib-compile-schemas /usr/share/glib-2.0/schemas/ 1> /dev/null 2> /dev/null
chroot . /usr/bin/gio-querymodules /usr/lib/gio/modules/ 1> /dev/null 2> /dev/null

==> glib2-2.36.4-arm-1.tgz: install/doinst.sh <==
( cd usr/doc/glib-2.36.4 ; rm -rf html )
( cd usr/doc/glib-2.36.4 ; ln -sf /usr/share/gtk-doc/html/gobject html )
( cd usr/lib ; rm -rf libgmodule-2.0.so )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.3600.4 libgmodule-2.0.so )
( cd usr/lib ; rm -rf libgmodule-2.0.so.0 )
( cd usr/lib ; ln -sf libgmodule-2.0.so.0.3600.4 libgmodule-2.0.so.0 )
( cd usr/lib ; rm -rf libgthread-2.0.so.0 )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.3600.4 libgthread-2.0.so.0 )
( cd usr/lib ; rm -rf libgio-2.0.so )
( cd usr/lib ; ln -sf libgio-2.0.so.0.3600.4 libgio-2.0.so )
( cd usr/lib ; rm -rf libgobject-2.0.so.0 )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.3600.4 libgobject-2.0.so.0 )
( cd usr/lib ; rm -rf libglib-2.0.so )
( cd usr/lib ; ln -sf libglib-2.0.so.0.3600.4 libglib-2.0.so )
( cd usr/lib ; rm -rf libgio-2.0.so.0 )
( cd usr/lib ; ln -sf libgio-2.0.so.0.3600.4 libgio-2.0.so.0 )
( cd usr/lib ; rm -rf libglib-2.0.so.0 )
( cd usr/lib ; ln -sf libglib-2.0.so.0.3600.4 libglib-2.0.so.0 )
( cd usr/lib ; rm -rf libgthread-2.0.so )
( cd usr/lib ; ln -sf libgthread-2.0.so.0.3600.4 libgthread-2.0.so )
( cd usr/lib ; rm -rf libgobject-2.0.so )
( cd usr/lib ; ln -sf libgobject-2.0.so.0.3600.4 libgobject-2.0.so )

# Handle the incoming configuration files:
config() {
  for infile in $1; do
    NEW="$infile"
    OLD="`dirname $NEW`/`basename $NEW .new`"
    # If there's no config file by that name, mv it over:
    if [ ! -r $OLD ]; then
      mv $NEW $OLD
    elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then
      # toss the redundant copy
      rm $NEW
    fi
    # Otherwise, we leave the .new copy for the admin to consider...
  done
}

# Prepare the new configuration files
for file in etc/profile.d/libglib2.csh.new etc/profile.d/libglib2.sh.new ; do
  if test -e $(dirname $file)/$(basename $file .new) ; then
    if [ ! -x $(dirname $file)/$(basename $file .new) ]; then
      chmod 644 $file
     else
      chmod 755 $file
    fi
  fi
  config $file
done

# Try to run these.  If they fail, no biggie.
chroot . /usr/bin/glib-compile-schemas /usr/share/glib-2.0/schemas/ 1> /dev/null 2> /dev/null
chroot . /usr/bin/gio-querymodules /usr/lib/gio/modules/ 1> /dev/null 2> /dev/null
